description_drug<-function(){
cat("****************************************************************************\n")
cat("     drug/trt. code#1: Ref. product                                         \n")
cat("     drug/trt. code#2: Test product                                         \n")
cat("****************************************************************************\n")
cat("\n")
}
